function varargout = Removenoise(varargin)
% REMOVENOISE MATLAB code for Removenoise.fig
%      REMOVENOISE, by itself, creates a new REMOVENOISE or raises the existing
%      singleton*.
%
%      H = REMOVENOISE returns the handle to a new REMOVENOISE or the handle to
%      the existing singleton*.
%
%      REMOVENOISE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in REMOVENOISE.M with the given input arguments.
%
%      REMOVENOISE('Property','Value',...) creates a new REMOVENOISE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Removenoise_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Removenoise_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Removenoise

% Last Modified by GUIDE v2.5 11-Nov-2021 15:56:14

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Removenoise_OpeningFcn, ...
                   'gui_OutputFcn',  @Removenoise_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Removenoise is made visible.
function Removenoise_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Removenoise (see VARARGIN)

% Choose default command line output for Removenoise
handles.output = hObject;
if(nargin==5)&&(strcmp(varargin{1},'compid'))
    set(hObject,'userdata',varargin{2});
    set(handles.compid,'string',varargin{2});
end

    movegui(hObject, 'center'); 
% Update handles structure
guidata(hObject, handles);
uiwait;

% UIWAIT makes Removenoise wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Removenoise_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
varargout{2}=get(handles.ok,'userdata');

function compid_Callback(hObject, eventdata, handles)


function compid_CreateFcn(hObject, eventdata, handles)

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function ok_Callback(hObject, eventdata, handles)
compid=get(handles.compid,'string');
% handles.output=compid;
set(hObject,'userdata',compid);
guidata(hObject, handles);
uiresume;
function reset_Callback(hObject, eventdata, handles)
set(handles.compid,'string',get(handles.figure1,'userdata')) ;
